@@ -1,3 +1,6 @@
+from .time import TimedFunction
+
+@TimedFunction
 def binary_search(arr, target):
     low = 0
     high = len(arr) - 1
@@ -9,4 +12,4 @@ def binary_search(arr, target):
             low = mid + 1
         else:
             high = mid - 1
-    return -1
\ No newline at end of file
+    return -1
