@@ -1,3 +1,6 @@
+from .time import TimedFunction
+
+@TimedFunction
 def bubble_sort(arr):
     n = len(arr)
     for i in range(n - 1):
