@@ -1,3 +1,6 @@
+from .time import TimedFunction
+
+@TimedFunction
 def dfs(graph, start, visited=None):
     if visited is None:
         visited = set()
