@@ -1,3 +1,6 @@
+from .time import TimedFunction
+
+@TimedFunction
 def greedy_set_cover(universe, subsets):
     selected_subsets = []  # 存储被选择的子集
 
@@ -14,4 +17,4 @@ def greedy_set_cover(universe, subsets):
         universe -= max_covered  # 从宇宙集合中移除被覆盖的元素
         selected_subsets.append(best_subset)  # 将最优子集加入到被选择的子集中
 
-    return selected_subsets
\ No newline at end of file
+    return selected_subsets
