@@ -1,3 +1,6 @@
+import .time from TimedFunction
+
+@TimedFunction
 def counting_sort(arr, exp):
     n = len(arr)
     output = [0] * n
@@ -33,4 +36,4 @@ def radix_sort(arr):
         counting_sort(arr, exp)
         exp *= 10
 
-    return arr
\ No newline at end of file
+    return arr
