@@ -1,3 +1,6 @@
+import .time from TimedFunction
+
+@TimedFunction
 def selection_sort(arr):
     n = len(arr)
     for i in range(n):
