@@ -1,3 +1,6 @@
+import .time from TimedFunction
+
+@TimedFunction
 def vigenere_cipher(text, key):
     result = ""
     key_index = 0
